import sqlalchemy as sa
from ringo.model import Base
from ringo.model.base import BaseItem
from ringo.model.mixins import Owned, Meta
from ringo_contact.model import Contactable


class Beneficiary(Contactable, BaseItem, Owned, Meta, Base):
    """Public or private body responsible for initiating (or both
    initiating and implementing) an :class:`.Operation`.

    In case the beneficiary is implementing a :class:`.Project` by its
    own the beneficiary should create a organisation to be primus inter
    pares.
    """
    __tablename__ = 'beneficiarys'
    _modul_id = 1005
    id = sa.Column(sa.Integer, primary_key=True)
    name = sa.Column('name', sa.String, nullable=False, default='')
    """Name of the beneficiary"""
    organisations = sa.orm.relation("Organisation", cascade="all")
    """List of :class:`.Organisation` instances which are linked to the
    beneficiary."""
    phone = sa.Column('phone', sa.String, nullable=False, default='')
    """Phone number of the beneficiary"""
    fax = sa.Column('fax', sa.String, nullable=False, default='')
    """Fax number of the beneficiary"""
    email = sa.Column('email', sa.String, nullable=False, default='')
    """Email of the beneficiary"""
    address_city = sa.Column('address_city', sa.String,
                             nullable=False, default='')
    """City of the beneficiary"""
    address_postal = sa.Column('address_postal', sa.String,
                               nullable=False, default='')
    """Postal code of the beneficiary"""
    address_street = sa.Column('address_street', sa.String,
                               nullable=False, default='')
    """Street of the beneficiary"""

    # Name and ids for reportserver filtering
    beneficiary_id = sa.Column('beneficiary_id', sa.String)
    beneficiary_name = sa.Column('beneficiary_name', sa.String)
    regioncategory_id = sa.Column("regioncategory_id", sa.Integer)
    nuts1 = sa.Column("nuts1", sa.String(3))

    # for target system
    oi_target_number = sa.Column('oi_target_number', sa.Integer)
    ri_target_percent = sa.Column('ri_target_percent', sa.Integer)
